# Schema Agents

A schema-based LLM framework for building multi-agent collaborative systems.

## Getting Started

See [example](./scripts/alice_cooker_example.py) for a simple example of how to use the framework.

## Development

Create a conda environment and install dependencies:

```bash
conda create -n schema-agents python=3.10
conda activate schema-agents
```

```
conda install faiss-cpu -c conda-forge
pip install -r requirements_test.txt
pip install -e .
```
